<?php
/**
 * Creating or editting an item
 *
 * $Horde: thor/item.php,v 1.15 2005/01/03 14:35:33 jan Exp $
 *
 * Copyright 2003-2005 Carlos Pedrinaci <cpedrinaci@yahoo.es>
 *
 * See the enclosed file COPYING for license information (GPL).  If you
 * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
 */

@define('THOR_BASE', dirname(__FILE__));
require_once THOR_BASE . '/lib/base.php';
require_once 'Horde/Variables.php';

$renderer = &new Horde_Form_Renderer();
$vars = &Variables::getDefaultVariables();

// Get Project information
$projectID = $vars->get('project_id');
if (empty($projectID)) {
    header('Location: ' . Horde::applicationUrl('list.php', true));
    exit;
}
$project = &$thor->_projectsContainer->getProject($projectID);
if (is_a($project, 'PEAR_Error')) {
    $notification->push(_("Unable to retrieve the project"), 'horde.error');
    header('Location: ' . Horde::applicationUrl('list.php', true));
    exit;
}

if (!$project->isUserOfKind(Auth::getAuth(), USERS_ADMINS)) {
    // It isn't an admin
    $notification->push(sprintf(_("You can't access that page: You are not an administrator for that project.")), 'horde.warning');
    header('Location: ' . Horde::applicationUrl('list.php', true));
    exit;
}

if ($project->data['project_status'] == THOR_STATUS_BLOCKED) {
    // The project is blocked -> don't allow team management
    $notification->push(sprintf(_("You can't access that page: the project has been blocked.")), 'horde.warning');
    header('Location: ' . Horde::applicationUrl('view.php?project_id=' . $projectID, true));
    exit;
}

$showConfirmation = false;
$itemID = $vars->get('item_id');
$actionID = $vars->get('actionID');

/* Page variables. */
$title = _("Items Management");

switch ($actionID) {
case DELETE_ITEM:
    $confirm = $vars->get('confirm');
	if ($confirm == _("Yes")) {
        // Delete the Item
        $result = $thor->_itemsContainer->deleteItem($itemID);
         if (is_a($result, 'PEAR_Error')) {
            $notification->push(_("Unable to remove the item from the DB."), 'horde.error');
            header('Location: ' . Horde::applicationUrl('view.php?project_id=' . $projectID, true));
            exit;
        } else {
            $notification->push(_("Item removed."), 'horde.success');
            header('Location: ' . Horde::applicationUrl('view.php?project_id=' . $projectID, true));
            exit;
        }
    } elseif (!isset($confirm)) {
        $showConfirmation = true;
    	$item = &$thor->_itemsContainer->getItem($itemID);
        if (is_a($item, 'PEAR_Error')) {
            $notification->push(_("Unable to retrieve the item"), 'horde.error');
            header('Location: ' . Horde::applicationUrl('view.php?project_id=' . $projectID, true));
            exit;
        }
        $confirmText = sprintf(_("Are you sure you want to delete the item '%s'?"), $item->getShortName());
    } else {
        header('Location: ' . Horde::applicationUrl('view.php?project_id=' . $projectID, true));
        exit;
    }
	break;

case SET_WRITE_PROTECTED:
    $item = &$thor->_itemsContainer->getItem($itemID);
    if (is_a($item, 'PEAR_Error')) {
        $notification->push(_("Unable to retrieve the item"), 'horde.error');
        header('Location: ' . Horde::applicationUrl('view.php?project_id=' . $projectID, true));
        exit;
    }
    $confirm = $vars->get('confirm');
    if ($confirm == _("Yes")) {
        // Write protect the Item
        $result = $item->setWriteProtected(true);
        if (is_a($result, 'PEAR_Error')) {
            $notification->push(_("Unable to write protect the item."), 'horde.error');
            header('Location: ' . Horde::applicationUrl('view.php?project_id=' . $projectID, true));
            exit;
        } else {
            $notification->push(_("Item write protected."), 'horde.success');
            header('Location: ' . Horde::applicationUrl('view.php?project_id=' . $projectID, true));
            exit;
        }

    } elseif (!isset($confirm)) {
        $showConfirmation = true;
        $confirmText = sprintf(_("Are you sure you want to write protect '%s'?"), $item->getShortName());
    } else {
        header('Location: ' . Horde::applicationUrl('view.php?project_id=' . $projectID, true));
        exit;
    }
    break;

case UNSET_WRITE_PROTECTED:
    $item = &$thor->_itemsContainer->getItem($itemID);
    if (is_a($item, 'PEAR_Error')) {
        $notification->push(_("Unable to retrieve the item"), 'horde.error');
        header('Location: ' . Horde::applicationUrl('view.php?project_id=' . $projectID, true));
        exit;
    }
    $confirm = $vars->get('confirm');
    if ($confirm == _("Yes")) {
        // Remove write protection
        $result = $item->setWriteProtected(false);
        if (is_a($result, 'PEAR_Error')) {
            $notification->push(_("Unable to remove item's write protection."), 'horde.error');
            header('Location: ' . Horde::applicationUrl('view.php?project_id=' . $projectID, true));
            exit;
        } else {
            $notification->push(_("Item's write protection removed."), 'horde.success');
            header('Location: ' . Horde::applicationUrl('view.php?project_id=' . $projectID, true));
            exit;
        }
    } elseif (!isset($confirm)) {
        $showConfirmation = true;
        $confirmText = sprintf(_("Are you sure you want to remove write protection of '%s'?"), $item->getShortName());
    } else {
        header('Location: ' . Horde::applicationUrl('view.php?project_id=' . $projectID, true));
        exit;
    }
    break;

case EDIT_ITEM:
    $form1 = &Horde_Form::singleton('ItemForm', $vars);
    $item = &$thor->_itemsContainer->getItem($itemID);
    if (is_a($item, 'PEAR_Error')) {
        $notification->push(_("Unable to retrieve the item"), 'horde.error');
        header('Location: ' . Horde::applicationUrl('list.php', true));
        exit;
    }
    $itemData = $item->toArray();
    $form1 = &Horde_Form::singleton('ItemForm', $vars);
    $form2 = &Horde_Form::singleton($itemData['item_kind'] .'Form', $vars);

    if ($form2->validate($vars) && $form1->validate($vars, true)) {
        // All is ok Save data
        $form1->getInfo($vars, $info);
        $form2->getInfo($vars, $info);

        $result = $thor->_itemsContainer->saveItem($info);
        if (is_a($result, 'PEAR_Error')) {
            $notification->push(_("Unable to store item's information."), 'horde.error');
            header('Location: ' . Horde::applicationUrl('list.php', true));
            exit;
        } else {
            $notification->push(_("Item Modified."), 'horde.success');
            header('Location: ' . Horde::applicationUrl('view_item.php?item_id=' . $itemData['item_id'], true));
            exit;
        }
    } else {
        if (!$form1->isSubmitted() && !$form2->isSubmitted()) {
            $vars = &new Variables($itemData);
        }
    }

    require THOR_TEMPLATES . '/common-header.inc';
    require THOR_TEMPLATES . '/menu.inc';
    $form2->open($renderer, $vars, 'item.php?actionID=' . $actionID, 'post');

    // Print both forms
    $form1->preserve($vars);
    $renderer->beginActive($form1->getTitle());
    $renderer->renderFormActive($form1, $vars);
    $renderer->beginActive($form2->getTitle());
    $renderer->renderFormActive($form2, $vars);
    $renderer->submit(_("Save Changes"), _("Undo Changes"));
    $renderer->end();
    $form2->close($renderer);

    break;

case CREATE_ITEM:
    $form1 = &Horde_Form::singleton('ItemForm', $vars);
    $currentForm = $vars->get('formname');
    if (isset($currentForm)) $form1->setSubmitted();
    $valid1 = $form1->validate($vars);
    if ($form1->isSubmitted() && $form1->validate($vars, true)) {

        $item_kind = $vars->get('item_kind');
        require_once THOR_LIBS . '/Item/' . $item_kind . '.php';
        $class = $item_kind . 'Form';

        $form2 = &Horde_Form::singleton($class, $vars);

        if ($form2->validate($vars)) {
            $form1->getInfo($vars, $info);
            $form2->getInfo($vars, $info);

            /* Save the Item */
            $id = $thor->_itemsContainer->saveItem($info);
            if (is_a($id, 'PEAR_Error')) {
                $notification->push(_("Unable to store item's information."), 'horde.error');
                header('Location: ' . Horde::applicationUrl('list.php', true));
                exit;
            } else {
                /* Initialize the Item */
                $item = &$thor->_itemsContainer->getItem($id);
                $result = $item->initialize();
                if (is_a($result, 'PEAR_Error')) {
                    $notification->push(_("Could not initialize the Item."), 'horde.error');
                    header('Location: ' . Horde::applicationUrl('list.php', true));
                    exit;
                }
                $notification->push(_("Item Created"), 'horde.success');
                header('Location: ' . Horde::applicationUrl('view.php?project_id=' . $projectID, true));
                exit;
            }
        }

        require THOR_TEMPLATES . '/common-header.inc';
        require THOR_TEMPLATES . '/menu.inc';

        $form2->open($renderer, $vars, 'item.php?actionID=' . $actionID, 'post');

        // Preserve previous form.
        $form1->preserve($vars);
        $renderer->beginInactive($form1->getTitle());
        $renderer->renderFormInactive($form1, $vars);
        $renderer->end();

        if ($vars->get('formname') == 'itemform') {
            $form2->clearValidation();
        }
        $renderer->beginActive($form2->getTitle());
        $renderer->renderFormActive($form2, $vars);
        $renderer->submit(_("Create Item"), _("Reset"));
        $renderer->end();
        $form2->close($renderer);
    } else {
        // Form1 not valid
        require THOR_TEMPLATES . '/common-header.inc';
        require THOR_TEMPLATES . '/menu.inc';
        $form1->setButtons(_("Continue"), _("Reset"));
        $form1->renderActive($renderer, $vars, 'item.php', 'post');
    }
    break;

default:
	header('Location: ' . Horde::applicationUrl('view.php?project_id=' . $projectID, true));
    exit;
}

if ($showConfirmation) {
    require THOR_TEMPLATES . '/common-header.inc';
    require THOR_TEMPLATES . '/menu.inc';
    require THOR_TEMPLATES . '/item/confirmation.inc';
    $project->showInformation(false, true);
    $item->showInformation(true);
}

require $registry->get('templates', 'horde') . '/common-footer.inc';