<?php
/**
 * DataTreeObject_SampleProject Class.
 * This is just an example on how to create a new kind of Project.
 * Take care of the "naming conventions" such as:
 *   1.- the Class name: DataTreeObject_XXXX
 *   2.- The $_objectType variable: thor/XXXX
 *   3.- There has to exist a class called XXXXForm for creating or editting projects
 *
 * $Horde: thor/lib/Project/SampleProject.php,v 1.8 2004/08/24 20:14:46 carlos Exp $
 *
 * @author  Carlos Pedrinaci <cpedrinaci@yahoo.es>
 * @version $Revision: 1.8 $
 * @package Thor
 */
class DataTreeObject_SampleProject extends DataTreeObject_Project {

    /**
     * Variable required for Dynamic Binding of Projects
     */
    var $_objectType = 'thor/SampleProject';

    function DataTreeObject_SoftwareProject($name)
    {
        parent::DataTreeObject_Project($name);
    }
       
    function _toAttributes()
    {                                    
        $attributes[] = array('name'  => 'sample',
                              'key'   => 'attribute1',
                              'value' => $this->data['sample_attribute1']);
        $attributes[] = array('name'  => 'sample',
                              'key'   => 'attribute2',
                              'value' => $this->data['sample_attribute2']);
        $attributes[] = array('name'  => 'sample',
                              'key'   => 'attribute3',
                              'value' => $this->data['sample_attribute3']);     
       
        return array_merge(parent::_toAttributes(),$attributes);
    }
    
    function toArray()
    {
        $array['sample_attribute1'] = $this->data['sample_attribute1'];
        $array['sample_attribute2'] = $this->data['sample_attribute2'];   
        $array['sample_attribute3'] = $this->data['sample_attribute3'];  
        return array_merge(parent::toArray(), $array);     
    }
    
    function fromArray(&$info)
    {
        $this->data['sample_attribute1'] = $info['sample_attribute1'];    
        $this->data['sample_attribute2'] = $info['sample_attribute2'];
        $this->data['sample_attribute3'] = $info['sample_attribute3'];
        parent::fromArray($info);
    }
    
    /**
     * Shows the Project information
     * Every link is maintained using the same base url
     *
     * @param string optional $insertBreak Insert a break before adding the content?
     * @param boolean optional $short Show all the information if false.
     *                                                 Use a summarised template if True.
     */
    function showInformation($insertBreak = false, $short = false)
    {   
        global $prefs, $thor;
        
        $projectData = $this->toArray();
        $projectName = $this->getName();
        $leftHeaderText = '';
        $parents = explode(':', $projectName);
        if (!empty($parents)) {
            foreach($parents as $id => $parentName) {
                $cumName = ($id == 0) ? $cumName = $parentName : $cumName = $cumName . ':' . $parentName;
                if ($parentName != $projectData['project_name']) {
                    $baseurl = Util::removeParameter(Horde::selfUrl(true), 'project_id');
                    $url = Util::addParameter($baseurl, 'project_id', $thor->_projectsContainer->getProjectId($cumName));
                    $parentLink = Horde::link($url, $parentName) . htmlspecialchars($parentName) . '</a>';
                    $leftHeaderText = $leftHeaderText . $parentLink . ' : ' ;
                }
            }
        } 
        $leftHeaderText = $leftHeaderText . htmlspecialchars($projectData['project_name']);
        $rightHeaderText = _("Since: ") . strftime($prefs->getValue('date_format'), $projectData['project_creation_date']);
        require THOR_TEMPLATES . '/section-header.inc';
        if ($short) {
            require THOR_TEMPLATES . '/view/SampleProject/short_description.inc';
        } else {
            require THOR_TEMPLATES . '/view/SampleProject/description.inc';
        }
        require THOR_TEMPLATES . '/view/footer.inc';
    }
    
    function initialize()
    {
        return parent::initialize();
    }

    
    function _destroy()
    {
        return parent::_destroy();
    }
}

/**
 * SampleProjectForm Class
 *
 * $Horde: thor/lib/Project/SampleProject.php,v 1.8 2004/08/24 20:14:46 carlos Exp $
 *
 * @author  Carlos Pedrinaci <cpedrinaci@yahoo.es>
 * @version $Revision: 1.8 $
 * @package Thor
 */
class SampleProjectForm extends Horde_Form {

    var $_useFormToken = false;

    function SampleProjectForm(&$vars)
    {
        $pid = $vars->get('project_id');
        $title = empty($pid) ? _("Create Project - Step 2") : _("Edit Sample Project");
        parent::Horde_Form($vars, $title);
        $this->addVariable(_("Sample Attribute 1"), 'sample_attribute1', 'text', true);
        $this->addVariable(_("Sample Attribute 2"), 'sample_attribute2', 'longtext', true, false, null);
        $this->addVariable(_("Sample Attribute 3"), 'sample_attribute3', 'text', true);
    }
    
}